@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2017-02-19'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,6 +66,12 @@ our $scenario = {
             function => 'union',
             code_template => 'my $s1 = Set::Tiny->new(@{<set1>}); my $s2 = Set::Tiny->new(@{<set2>}); $s1->union($s2)',
         },
+        {
+            tags => ['op:union'],
+            module => 'List::Collection',
+            function => 'union',
+            code_template => '[List::Collection::union(<set1>, <set2>)]',
+        },
 
         # SYMDIFF
         {
@@ -123,6 +129,12 @@ our $scenario = {
             function => 'symmetric_difference',
             code_template => 'my $s1 = Set::Tiny->new(@{<set1>}); my $s2 = Set::Tiny->new(@{<set2>}); $s1->symmetric_difference($s2)',
         },
+        {
+            tags => ['op:symdiff'],
+            module => 'List::Collection',
+            function => 'complement',
+            code_template => '[List::Collection::complement(<set1>, <set2>)]',
+        },
 
         # DIFF
         {
@@ -167,6 +179,12 @@ our $scenario = {
             function => 'difference',
             code_template => 'my $s1 = Set::Tiny->new(@{<set1>}); my $s2 = Set::Tiny->new(@{<set2>}); $s1->difference($s2)',
         },
+        {
+            tags => ['op:diff'],
+            module => 'List::Collection',
+            function => 'subtract',
+            code_template => '[List::Collection::subtract(<set1>, <set2>)]',
+        },
 
         # INTERSECT
         {
@@ -211,6 +229,12 @@ our $scenario = {
             function => 'intersection',
             code_template => 'my $s1 = Set::Tiny->new(@{<set1>}); my $s2 = Set::Tiny->new(@{<set2>}); $s1->intersection($s2)',
         },
+        {
+            tags => ['op:intersect'],
+            module => 'List::Collection',
+            function => 'intersect',
+            code_template => '[List::Collection::intersect(<set1>, <set2>)]',
+        },
     ],
 
     # XXX: add more datasets (larger data, etc)
@@ -255,7 +279,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.10 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2017-01-25.
+This document describes version 0.11 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2017-02-19.
 
 =head1 SYNOPSIS
 
@@ -283,6 +307,8 @@ L<Array::Set> 0.05
 
 L<Array::Utils> 0.5
 
+L<List::Collection> 0.0.4
+
 L<List::MoreUtils> 0.416
 
 L<List::MoreUtils::PP> 0.416
@@ -371,6 +397,14 @@ Code template:
 
 
 
+=item * List::Collection::union (perl_code) [op:union]
+
+Code template:
+
+ [List::Collection::union(<set1>, <set2>)]
+
+
+
 =item * Array::Utils::array_diff (perl_code) [op:symdiff]
 
 Code template:
@@ -443,6 +477,14 @@ Code template:
 
 
 
+=item * List::Collection::complement (perl_code) [op:symdiff]
+
+Code template:
+
+ [List::Collection::complement(<set1>, <set2>)]
+
+
+
 =item * Array::Utils::array_minus (perl_code) [op:diff]
 
 Code template:
@@ -499,6 +541,14 @@ Code template:
 
 
 
+=item * List::Collection::subtract (perl_code) [op:diff]
+
+Code template:
+
+ [List::Collection::subtract(<set1>, <set2>)]
+
+
+
 =item * Array::Utils::intersect (perl_code) [op:intersect]
 
 Code template:
@@ -555,6 +605,14 @@ Code template:
 
 
 
+=item * List::Collection::intersect (perl_code) [op:intersect]
+
+Code template:
+
+ [List::Collection::intersect(<set1>, <set2>)]
+
+
+
 =back
 
 =head1 BENCHMARK DATASETS
@@ -569,78 +627,86 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m SetOperationModules >>):
 
  #table1#
  +---------------------------------------+---------+-----------+------------+------------+---------+---------+
- | participant                           | dataset | rate (/s) | time (ms)  | vs_slowest |  errors | samples |
+ | participant                           | dataset | rate (/s) |  time (ms) | vs_slowest |  errors | samples |
  +---------------------------------------+---------+-----------+------------+------------+---------+---------+
- | Array::AsObject::symmetric_difference | num100  |      79   | 13         |     1      | 9.1e-05 |      20 |
- | Array::AsObject::intersection         | num100  |     160   |  6.2       |     2      | 6.1e-05 |      20 |
- | Array::AsObject::difference           | num100  |     330   |  3.1       |     4.1    | 4.3e-06 |      22 |
- | Set::Array::intersection              | num100  |     440   |  2.3       |     5.6    |   7e-06 |      36 |
- | Set::Scalar::intersection             | num100  |    1410   |  0.711     |    17.9    | 4.3e-07 |      20 |
- | Set::Scalar::union                    | num100  |    1500   |  0.68      |    19      | 9.1e-07 |      20 |
- | Set::Scalar::difference               | num100  |    1550   |  0.644     |    19.7    | 2.1e-07 |      20 |
- | Set::Scalar::symmetric_difference     | num100  |    2120   |  0.472     |    26.9    | 4.3e-07 |      20 |
- | Array::AsObject::symmetric_difference | num10   |    4000   |  0.3       |    50      | 2.9e-06 |      23 |
- | Set::Object::symmetric_difference     | num100  |    7000   |  0.14      |    89      | 2.3e-07 |      28 |
- | Array::AsObject::intersection         | num10   |    7666   |  0.130446  |    97.3485 | 3.4e-11 |      22 |
- | Set::Scalar::intersection             | num10   |    7700   |  0.13      |    98      | 2.2e-07 |      29 |
- | Array::AsObject::union                | num100  |    7900   |  0.13      |   100      | 2.3e-07 |      28 |
- | Set::Scalar::union                    | num10   |    8000   |  0.12      |   100      | 1.9e-07 |      25 |
- | Set::Object::intersection             | num100  |    8100   |  0.12      |   100      | 1.8e-07 |      28 |
- | Set::Scalar::difference               | num10   |    8200   |  0.12      |   100      | 2.3e-07 |      27 |
- | Set::Array::symmetric_difference      | num100  |    9000   |  0.11      |   110      | 4.3e-07 |      20 |
- | Set::Array::difference                | num100  |   10000   |  0.097     |   130      | 1.3e-07 |      20 |
- | Set::Object::union                    | num100  |   10000   |  0.095     |   130      | 1.1e-07 |      20 |
- | Set::Tiny::symmetric_difference       | num100  |   12000   |  0.086     |   150      |   1e-07 |      22 |
- | Set::Object::difference               | num100  |   12000   |  0.082     |   150      | 1.2e-07 |      24 |
- | Set::Array::union                     | num100  |   12000   |  0.08      |   160      | 9.7e-08 |      24 |
- | Set::Tiny::difference                 | num100  |   13000   |  0.079     |   160      | 1.1e-07 |      20 |
- | Set::Tiny::union                      | num100  |   13000   |  0.079     |   160      | 1.9e-07 |      31 |
- | Set::Scalar::symmetric_difference     | num10   |   13000   |  0.0769    |   165      | 2.7e-08 |      20 |
- | Set::Tiny::intersection               | num100  |   15000   |  0.068     |   190      |   8e-08 |      20 |
- | Array::Set::set_symdiff               | num100  |   14800   |  0.0676    |   188      | 2.7e-08 |      20 |
- | Array::Set::set_intersect             | num100  |   15551.5 |  0.0643027 |   197.484  | 9.8e-12 |      22 |
- | Array::Set::set_union                 | num100  |   17300   |  0.0578    |   220      | 2.7e-08 |      20 |
- | Array::AsObject::difference           | num10   |   18000   |  0.0555    |   229      | 2.7e-08 |      20 |
- | List::MoreUtils::PP::singleton        | num100  |   18000   |  0.055     |   230      | 1.1e-07 |      20 |
- | Array::Utils::array_diff              | num100  |   19000   |  0.0526    |   241      | 2.5e-08 |      23 |
- | Array::Set::set_diff                  | num100  |   21000   |  0.047     |   270      | 6.4e-08 |      22 |
- | Array::Utils::array_minus             | num100  |   21800   |  0.0459    |   276      | 1.2e-08 |      24 |
- | Array::Utils::intersect               | num100  |   21884.2 |  0.0456952 |   277.901  | 3.4e-11 |      20 |
- | List::MoreUtils::PP::uniq             | num100  |   24000   |  0.042     |   300      | 5.3e-08 |      20 |
- | Set::Array::intersection              | num10   |   25605   |  0.039055  |   325.15   | 1.8e-10 |      20 |
- | List::MoreUtils::XS::singleton        | num100  |   30088.2 |  0.0332356 |   382.083  |   0     |      20 |
- | List::MoreUtils::XS::uniq             | num100  |   44000   |  0.023     |   560      | 2.7e-08 |      20 |
- | Set::Object::symmetric_difference     | num10   |   45000   |  0.022     |   570      | 2.7e-08 |      20 |
- | Set::Array::difference                | num10   |   47000   |  0.021     |   590      | 5.2e-08 |      27 |
- | Set::Array::symmetric_difference      | num10   |   49000   |  0.02      |   630      | 2.7e-08 |      30 |
- | Array::AsObject::union                | num10   |   53498   |  0.018692  |   679.36   | 4.8e-11 |      29 |
- | Set::Object::intersection             | num10   |   66400   |  0.0151    |   843      | 6.7e-09 |      20 |
- | Set::Array::union                     | num10   |   66600   |  0.015     |   846      | 6.7e-09 |      20 |
- | Set::Object::union                    | num10   |   80000   |  0.013     |  1000      | 1.3e-08 |      20 |
- | Set::Object::difference               | num10   |   92700   |  0.0108    |  1180      | 3.3e-09 |      20 |
- | Set::Tiny::symmetric_difference       | num10   |   97000   |  0.01      |  1200      | 1.3e-08 |      21 |
- | Set::Tiny::difference                 | num10   |  110000   |  0.0091    |  1400      | 2.6e-08 |      26 |
- | Set::Tiny::union                      | num10   |  110000   |  0.0091    |  1400      |   1e-08 |      20 |
- | Array::Set::set_symdiff               | num10   |  127000   |  0.0079    |  1610      | 2.8e-09 |      29 |
- | Set::Tiny::intersection               | num10   |  130000   |  0.00767   |  1660      | 3.2e-09 |      22 |
- | Array::Set::set_intersect             | num10   |  133000   |  0.0075    |  1690      | 3.3e-09 |      20 |
- | Array::Set::set_union                 | num10   |  140000   |  0.0069    |  1800      | 8.9e-09 |      25 |
- | Array::Utils::array_diff              | num10   |  156400   |  0.0063939 |  1986.1    | 3.4e-11 |      36 |
- | List::MoreUtils::PP::singleton        | num10   |  170000   |  0.0061    |  2100      | 6.7e-09 |      20 |
- | Array::Set::set_diff                  | num10   |  167000   |  0.00598   |  2120      |   5e-09 |      20 |
- | Array::Utils::unique                  | num100  |  170000   |  0.0057    |  2200      | 6.7e-09 |      20 |
- | Array::Utils::intersect               | num10   |  192000   |  0.00521   |  2440      | 1.7e-09 |      20 |
- | Array::Utils::array_minus             | num10   |  192000   |  0.0052    |  2440      | 1.3e-09 |      32 |
- | List::MoreUtils::PP::uniq             | num10   |  214000   |  0.00468   |  2710      | 1.7e-09 |      20 |
- | List::MoreUtils::XS::singleton        | num10   |  303000   |  0.0033    |  3840      | 1.6e-09 |      22 |
- | List::MoreUtils::XS::uniq             | num10   |  380000   |  0.0027    |  4800      | 6.7e-09 |      20 |
- | Array::Utils::unique                  | num10   |  585600   |  0.001708  |  7436      | 9.5e-11 |      32 |
+ | Array::AsObject::symmetric_difference | num100  |     112.6 | 8.878      |      1     | 4.3e-07 |      20 |
+ | Array::AsObject::intersection         | num100  |     230.2 | 4.343      |      2.044 |   2e-07 |      22 |
+ | Array::AsObject::difference           | num100  |     470   | 2.13       |      4.17  | 2.6e-07 |      21 |
+ | List::Collection::complement          | num100  |     561   | 1.78       |      4.98  | 9.1e-07 |      20 |
+ | Set::Array::intersection              | num100  |     622   | 1.61       |      5.52  | 1.3e-06 |      20 |
+ | List::Collection::union               | num100  |     940   | 1.1        |      8.4   | 1.2e-06 |      20 |
+ | List::Collection::intersect           | num100  |    1400   | 0.71       |     12     | 1.1e-06 |      20 |
+ | Set::Scalar::intersection             | num100  |    2020   | 0.495      |     17.9   | 2.7e-07 |      20 |
+ | Set::Scalar::union                    | num100  |    2120   | 0.472      |     18.8   | 3.7e-07 |      20 |
+ | Set::Scalar::difference               | num100  |    2230   | 0.449      |     19.8   | 4.2e-07 |      21 |
+ | Set::Scalar::symmetric_difference     | num100  |    3010   | 0.332      |     26.7   | 2.1e-07 |      20 |
+ | Array::AsObject::symmetric_difference | num10   |    5100   | 0.196      |     45.3   | 4.6e-08 |      27 |
+ | List::Collection::complement          | num10   |    8100   | 0.12       |     72     | 6.9e-07 |      20 |
+ | Set::Object::symmetric_difference     | num100  |   10000   | 0.1        |     88     | 1.3e-07 |      20 |
+ | Set::Object::intersection             | num100  |   11300   | 0.0885     |    100     |   8e-08 |      20 |
+ | Array::AsObject::union                | num100  |   11328.9 | 0.0882696  |    100.58  |   0     |      20 |
+ | Array::AsObject::intersection         | num10   |   11500   | 0.0872     |    102     | 2.5e-08 |      23 |
+ | Set::Scalar::intersection             | num10   |   12000   | 0.087      |    100     | 1.7e-07 |      31 |
+ | Set::Scalar::union                    | num10   |   12000   | 0.0835     |    106     | 2.7e-08 |      20 |
+ | Set::Scalar::difference               | num10   |   12500   | 0.0802     |    111     | 2.7e-08 |      20 |
+ | Set::Array::difference                | num100  |   13200   | 0.076      |    117     | 2.5e-08 |      22 |
+ | Set::Array::symmetric_difference      | num100  |   13000   | 0.076      |    120     | 7.8e-08 |      21 |
+ | Set::Object::union                    | num100  |   14000   | 0.072      |    120     |   1e-07 |      21 |
+ | Set::Object::difference               | num100  |   15000   | 0.069      |    130     | 1.1e-07 |      20 |
+ | Set::Tiny::symmetric_difference       | num100  |   16000   | 0.061      |    140     | 1.1e-07 |      20 |
+ | List::Collection::intersect           | num10   |   16000   | 0.061      |    150     | 9.7e-08 |      24 |
+ | List::Collection::union               | num10   |   17000   | 0.06       |    150     | 4.5e-07 |      20 |
+ | Set::Tiny::difference                 | num100  |   17400   | 0.0573     |    155     | 2.6e-08 |      21 |
+ | Set::Tiny::union                      | num100  |   18000   | 0.057      |    160     | 1.1e-07 |      20 |
+ | Set::Tiny::intersection               | num100  |   18000   | 0.055      |    160     | 1.1e-07 |      20 |
+ | Set::Scalar::symmetric_difference     | num10   |   18800   | 0.0532     |    167     | 2.7e-08 |      20 |
+ | Set::Array::union                     | num100  |   19100   | 0.0524     |    169     | 2.3e-08 |      28 |
+ | Array::Set::set_intersect             | num100  |   21000   | 0.047      |    190     | 1.6e-07 |      27 |
+ | Array::Set::set_symdiff               | num100  |   21200   | 0.0471     |    188     | 1.2e-08 |      25 |
+ | Array::Set::set_union                 | num100  |   22057.6 | 0.0453358  |    195.83  |   0     |      23 |
+ | Array::AsObject::difference           | num10   |   24076.9 | 0.0415336  |    213.758 |   0     |      20 |
+ | Array::Utils::array_diff              | num100  |   26000   | 0.038      |    230     | 4.2e-08 |      33 |
+ | List::MoreUtils::PP::singleton        | num100  |   27000   | 0.037      |    240     | 1.1e-08 |      30 |
+ | Array::Set::set_diff                  | num100  |   28500   | 0.0351     |    253     | 1.2e-08 |      24 |
+ | Array::Utils::array_minus             | num100  |   29000   | 0.035      |    250     | 1.9e-07 |      25 |
+ | Array::Utils::intersect               | num100  |   29300   | 0.0342     |    260     | 1.3e-08 |      22 |
+ | List::Collection::subtract            | num100  |   30400   | 0.0329     |    270     | 1.1e-08 |      30 |
+ | List::MoreUtils::PP::uniq             | num100  |   35000   | 0.028      |    320     | 4.4e-08 |      29 |
+ | Set::Array::intersection              | num10   |   37000   | 0.027      |    330     | 5.3e-08 |      20 |
+ | List::MoreUtils::XS::singleton        | num100  |   43400   | 0.023      |    386     | 6.7e-09 |      20 |
+ | List::MoreUtils::XS::uniq             | num100  |   56600   | 0.0177     |    502     | 5.4e-09 |      31 |
+ | Set::Object::symmetric_difference     | num10   |   63800   | 0.0157     |    567     | 5.8e-09 |      26 |
+ | Set::Array::difference                | num10   |   66800   | 0.015      |    593     | 6.7e-09 |      20 |
+ | Set::Array::symmetric_difference      | num10   |   73000   | 0.014      |    650     | 2.5e-08 |      22 |
+ | Array::AsObject::union                | num10   |   75000   | 0.013      |    670     | 2.2e-08 |      29 |
+ | Set::Object::intersection             | num10   |   94000   | 0.011      |    840     | 1.3e-08 |      20 |
+ | Set::Array::union                     | num10   |   95600   | 0.0105     |    848     | 3.1e-09 |      23 |
+ | Set::Object::union                    | num10   |  110000   | 0.0089     |   1000     | 1.1e-08 |      27 |
+ | Set::Object::difference               | num10   |  120000   | 0.0086     |   1000     | 1.2e-08 |      25 |
+ | Set::Tiny::symmetric_difference       | num10   |  130000   | 0.0075     |   1200     |   1e-08 |      20 |
+ | Set::Tiny::difference                 | num10   |  140000   | 0.007      |   1300     | 1.3e-08 |      20 |
+ | Set::Tiny::union                      | num10   |  150000   | 0.0067     |   1300     | 1.3e-08 |      20 |
+ | Set::Tiny::intersection               | num10   |  160000   | 0.0064     |   1400     | 1.3e-08 |      21 |
+ | Array::Set::set_symdiff               | num10   |  179258   | 0.00557856 |   1591.47  |   0     |      20 |
+ | Array::Set::set_union                 | num10   |  183000   | 0.00547    |   1620     | 1.4e-09 |      27 |
+ | Array::Set::set_intersect             | num10   |  184430   | 0.0054221  |   1637.4   |   0     |      20 |
+ | List::Collection::subtract            | num10   |  190000   | 0.00526    |   1690     | 1.3e-09 |      32 |
+ | Array::Utils::array_diff              | num10   |  220000   | 0.00455    |   1950     | 1.7e-09 |      20 |
+ | Array::Set::set_diff                  | num10   |  229376   | 0.00435965 |   2036.43  |   0     |      20 |
+ | List::MoreUtils::PP::singleton        | num10   |  243262   | 0.0041108  |   2159.71  |   0     |      20 |
+ | Array::Utils::unique                  | num100  |  260000   | 0.0038     |   2300     | 6.7e-09 |      20 |
+ | Array::Utils::intersect               | num10   |  263305   | 0.00379788 |   2337.66  |   0     |      20 |
+ | Array::Utils::array_minus             | num10   |  265000   | 0.00378    |   2350     | 3.8e-09 |      35 |
+ | List::MoreUtils::PP::uniq             | num10   |  315256   | 0.00317203 |   2798.88  |   0     |      20 |
+ | List::MoreUtils::XS::singleton        | num10   |  420000   | 0.0024     |   3700     | 2.5e-09 |      20 |
+ | List::MoreUtils::XS::uniq             | num10   |  520000   | 0.00192    |   4610     | 8.3e-10 |      20 |
+ | Array::Utils::unique                  | num10   |  850000   | 0.0012     |   7500     | 1.2e-09 |      20 |
  +---------------------------------------+---------+-----------+------------+------------+---------+---------+
 
 
@@ -650,16 +716,17 @@ Benchmark module startup overhead (C<< bencher -m SetOperationModules --module-s
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Set::Array          | 3.1                          | 6.4                | 22             |      21   |                   15   |        1   | 5.7e-05 |      21 |
- | Array::AsObject     | 2.2                          | 5.6                | 19             |      21   |                   15   |        1   | 8.1e-05 |      20 |
- | Set::Object         | 1                            | 4.4                | 16             |      17   |                   11   |        1.2 | 9.2e-05 |      20 |
- | Set::Scalar         | 1.2                          | 4.5                | 16             |      16   |                   10   |        1.3 | 5.4e-05 |      20 |
- | List::MoreUtils     | 1.1                          | 4.5                | 16             |      13   |                    7   |        1.6 | 9.2e-05 |      20 |
- | List::MoreUtils::PP | 1.6                          | 5                  | 19             |       9.9 |                    3.9 |        2.1 | 6.1e-05 |      20 |
- | Array::Set          | 2.7                          | 6                  | 24             |       9   |                    3   |        2.3 | 4.6e-05 |      20 |
- | Set::Tiny           | 0.93                         | 4.3                | 16             |       7.1 |                    1.1 |        2.9 | 2.3e-05 |      21 |
- | Array::Utils        | 1.9                          | 5.4                | 19             |       7   |                    1   |        3   | 4.9e-05 |      21 |
- | perl -e1 (baseline) | 0.9                          | 4                  | 20             |       6   |                    0   |        4   | 8.5e-05 |      20 |
+ | Set::Array          | 3                            | 6.5                | 26             |     14    |                  11.45 |       1    | 6.6e-05 |      21 |
+ | List::Collection    | 0.93                         | 4.3                | 20             |     14    |                  11.45 |       1    | 2.4e-05 |      20 |
+ | Array::AsObject     | 2.2                          | 5.6                | 23             |     14    |                  11.45 |       1    | 2.7e-05 |      20 |
+ | Set::Object         | 1                            | 4.4                | 20             |     11    |                   8.45 |       1.3  | 2.1e-05 |      20 |
+ | Set::Scalar         | 1.2                          | 4.5                | 20             |     10    |                   7.45 |       1.3  |   4e-05 |      20 |
+ | List::MoreUtils     | 1.1                          | 4.5                | 20             |      8.1  |                   5.55 |       1.7  | 2.9e-05 |      20 |
+ | List::MoreUtils::PP | 1.6                          | 5.1                | 23             |      5.6  |                   3.05 |       2.5  | 2.4e-05 |      20 |
+ | Array::Set          | 2.7                          | 6.1                | 28             |      5.1  |                   2.55 |       2.7  | 2.6e-05 |      20 |
+ | Set::Tiny           | 2.3                          | 5.8                | 27             |      3.7  |                   1.15 |       3.7  | 8.5e-06 |      20 |
+ | Array::Utils        | 1.9                          | 5.3                | 23             |      3.6  |                   1.05 |       3.9  | 2.9e-05 |      20 |
+ | perl -e1 (baseline) | 0.934                        | 4.34               | 20             |      2.55 |                   0    |       5.48 |   2e-06 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
@@ -694,7 +761,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
